export const __esModule: boolean;
export class V2TimGroupManager {
    /** @hidden */
    constructor(module: any);
    nativeModule: any;
    /**
     * ### 创建自定义群组
     */
    createGroup(groupType: any, groupName: any, groupID: any, notification: any, introduction: any, faceUrl: any, isAllMuted: any, ...args: any[]): any;
    /**
     * ### 获取当前用户已经加入的群列表
     *
     * @note
     * 注意:
     * - 直播群（AVChatRoom）不支持该 API
     * - 该接口有频限检测，SDK 限制调用频率为 1 秒 10 次，超过限制后会报 ERR_SDK_COMM_API_CALL_FREQUENCY_LIMIT （7008）错误
     */
    getJoinedGroupList(): any;
    /**
     * ### 拉取群资料
     * @param groupIDList - 群ID列表
     */
    getGroupsInfo(groupIDList: any): any;
    /**
     * ### 设置群信息
     * @param info - 需要设置的群信息
     */
    setGroupInfo(info: any): any;
    /**
     * ### 初始化群属性
     * @param groupID - 群ID
     * @param attributes - 属性
     *
     *
     * @note
     * 注意:
     *  - 目前只支持：直播群（ AVChatRoom）。
     */
    initGroupAttributes(groupID: any, attributes: any): any;
    /**
     * ### 设置群属性
     * @param groupID - 群ID
     * @param attributes - 属性
     *
     * @note
     * 注意:
     *  - 目前只支持：直播群（ AVChatRoom）。
     */
    setGroupAttributes(groupID: any, attributes: any): any;
    /**
     * ### 删除群指定属性
     * @param groupID - 群ID
     * @param keys - 群属性key
     *
     * @note
     * 注意:
     *  - 目前只支持：直播群（ AVChatRoom）。
     */
    deleteGroupAttributes(groupID: any, keys: any): any;
    /**
     * ### 获取群指定属性
     * @param groupID - 群ID
     * @param keys - 群属性key
     * @note
     * 注意:
     *  - 目前只支持：直播群（ AVChatRoom）。
     */
    getGroupAttributes(groupID: any, keys: any): any;
    /**
     * ### 获取群在线人数
     * @param groupID - 群ID
     *
     * @note
     * 注意:
     *  - 目前只支持：直播群（ AVChatRoom）。
     */
    getGroupOnlineMemberCount(groupID: any): any;
    /**
     * ### 获取群成员列表
     * @param groupID - 群ID
     * @param filter - 指定群成员类型
     * @param nextSeq - 分页拉取标志，第一次拉取填 0，回调成功如果 nextSeq 不为零，需要分页，传入再次拉取，直至为 0。
     * @param count - 拉群量
     * @param offset - 偏移量
     *
     * @note
     * 直播群（AVChatRoom）的特殊限制：
     * - 旗舰版支持拉取最近入群群成员最多 1000 人，新进来的成员排在前面。需要您购买旗舰版套餐且前往 控制台 开启开关。如果不开启开关，您只能像非旗舰版一样最多拉到 31 人（6.3 及以上版本支持）。
     * - 非旗舰版支持拉取最近入群群成员最多 31 人，新进来的成员排在前面。
     * - 程序重启后，请重新加入群组，否则拉取群成员会报 10007 错误码。
     * - 群成员资料信息仅支持 userID | nickName | faceURL | role 字段。
     * - filter 字段不支持管理员角色，即不支持管理员角色的拉取。如果您的业务逻辑依赖于管理员角色，可以使用群自定义字段 groupAttributes 管理该角色。
     */
    getGroupMemberList(groupID: any, filter: any, nextSeq: any, ...args: any[]): any;
    /**
     * ### 指定的群成员资料
     * @param groupID - 群ID
     * @param memberList - 成员ID数组
     */
    getGroupMembersInfo(groupID: any, memberList: any): any;
    /**
     * ### 修改指定的群成员资料
     * @param groupID - 群ID
     * @param userID - 用户ID
     * @param nameCard - 群名片
     * @param customInfo - 自定义信息
     */
    setGroupMemberInfo(groupID: any, userID: any, nameCard: any, customInfo: any): any;
    /**
     * ### 禁言（只有管理员或群主能够调用）
     * @param groupID - 群ID
     * @param userID - 用户ID
     * @param seconds - 禁言时间
     */
    muteGroupMember(groupID: any, userID: any, seconds: any): any;
    /**
     * 邀请用户进群
     * @param groupID - 群ID
     * @param userList - 用户ID数组
     */
    inviteUserToGroup(groupID: any, userList: any): any;
    /**
     * ### 踢用户出群
     * @param groupID - 群ID
     * @param memberList - 用户ID 数组
     */
    kickGroupMember(groupID: any, memberList: any): any;
    /**
     * ### 切换群成员的角色
     * @note
     * 请注意不同类型的群有如下限制：
     * - 公开群（Public）和会议群（Meeting）：只有群主才能对群成员进行普通成员和管理员之间的角色切换。
     * - 其他群不支持设置群成员角色。
     * - 转让群组请调用 transferGroupOwner 接口。
     * - 会议群（Meeting）切换群成员角色之后，不会有 onGrantAdministrator 和 onRevokeAdministrator 通知回调
     * - 切换的角色支持普通群成员（ V2TIM_GROUP_MEMBER_ROLE_MEMBER） 和管理员（V2TIM_GROUP_MEMBER_ROLE_ADMIN
     */
    setGroupMemberRole(groupID: any, userID: any, role: any): any;
    /**
     * ### 转让群主
     *
     * @note
     * 请注意不同类型的群有如下限制：
     * - 普通类型的群（Work、Public、Meeting）：只有群主才有权限进行群转让操作。
     * - 直播群（AVChatRoom）：不支持转让群主。
     */
    transferGroupOwner(groupID: any, userID: any): any;
    /**
     * ### 获取加群申请列表
     */
    getGroupApplicationList(): any;
    /**
     * ### 同意某一条加群申请
     */
    acceptGroupApplication(groupID: any, fromUser: any, toUser: any, reason: any, addTime: any, ...args: any[]): any;
    /**
     * ### 拒绝某一条加群申请
     */
    refuseGroupApplication(groupID: any, fromUser: any, toUser: any, type: any, addTime: any, reason: any): any;
    /**
     * ### 标记申请列表为已读
     */
    setGroupApplicationRead(): any;
    /**
     * ### 搜索群列表
     * SDK 会搜索群名称包含于关键字列表 keywordList 的所有群并返回群信息列表。关键字列表最多支持5个。
     * @note
     * 需要您购买旗舰版套餐
     */
    searchGroups(_ref: any): any;
    /**
     * ### 搜索指定的群成员资料
     * SDK 会在本地搜索指定群 ID 列表中，群成员信息（名片、好友备注、昵称、userID）包含于关键字列表 keywordList 的所有群成员并返回群 ID 和群成员列表的 map，关键字列表最多支持5个。
     * @note
     * 需要您购买旗舰版套餐
     */
    searchGroupMembers(_ref2: any): any;
    /**
     * ### 获取当前用户已经加入的支持话题的社群列表
     */
    getJoinedCommunityList(): any;
    /**
     * ### 创建话题
     */
    createTopicInCommunity(groupID: any, topicInfo: any): any;
    /**
     * ### 删除话题
     */
    deleteTopicFromCommunity(groupID: any, topicIDList: any): any;
    /**
     * ### 修改话题信息
     */
    setTopicInfo(topicInfo: any): any;
    /**
     * ### 获取话题列表
     *
     * @note
     * topicIDList 传空时，获取此社群下的所有话题列表
     */
    getTopicInfoList(groupID: any, topicIDList: any): any;
}
